# Detector geometry

EXtra-geom is a separate library for handling the geometry of multi-module detectors.
You can access it through the `extra.geom` module, e.g.:
```python
from extra.geom import AGIPD_1MGeometry
```

See the [EXtra-geom documentation](https://extra-geom.readthedocs.io) for
information about how to use it.
